# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_SEPARATE_METADATA = Metadata(
    id="1d308177c07e5b1ae6f2b81d40dccff5e71e5dbf.boutiques",
    name="cifti-separate",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiSeparateVolumeAllParameters = typing.TypedDict('CiftiSeparateVolumeAllParameters', {
    "@type": typing.NotRequired[typing.Literal["volume_all"]],
    "volume_out": str,
    "opt_roi_roi_out": typing.NotRequired[str | None],
    "opt_label_label_out": typing.NotRequired[str | None],
    "opt_crop": bool,
})
CiftiSeparateVolumeAllParametersTagged = typing.TypedDict('CiftiSeparateVolumeAllParametersTagged', {
    "@type": typing.Literal["volume_all"],
    "volume_out": str,
    "opt_roi_roi_out": typing.NotRequired[str | None],
    "opt_label_label_out": typing.NotRequired[str | None],
    "opt_crop": bool,
})


CiftiSeparateLabelParameters = typing.TypedDict('CiftiSeparateLabelParameters', {
    "@type": typing.NotRequired[typing.Literal["label"]],
    "structure": str,
    "label_out": str,
    "opt_roi_roi_out": typing.NotRequired[str | None],
})
CiftiSeparateLabelParametersTagged = typing.TypedDict('CiftiSeparateLabelParametersTagged', {
    "@type": typing.Literal["label"],
    "structure": str,
    "label_out": str,
    "opt_roi_roi_out": typing.NotRequired[str | None],
})


CiftiSeparateMetricParameters = typing.TypedDict('CiftiSeparateMetricParameters', {
    "@type": typing.NotRequired[typing.Literal["metric"]],
    "structure": str,
    "metric_out": str,
    "opt_roi_roi_out": typing.NotRequired[str | None],
})
CiftiSeparateMetricParametersTagged = typing.TypedDict('CiftiSeparateMetricParametersTagged', {
    "@type": typing.Literal["metric"],
    "structure": str,
    "metric_out": str,
    "opt_roi_roi_out": typing.NotRequired[str | None],
})


CiftiSeparateVolumeParameters = typing.TypedDict('CiftiSeparateVolumeParameters', {
    "@type": typing.NotRequired[typing.Literal["volume"]],
    "structure": str,
    "volume_out": str,
    "opt_roi_roi_out": typing.NotRequired[str | None],
    "opt_crop": bool,
})
CiftiSeparateVolumeParametersTagged = typing.TypedDict('CiftiSeparateVolumeParametersTagged', {
    "@type": typing.Literal["volume"],
    "structure": str,
    "volume_out": str,
    "opt_roi_roi_out": typing.NotRequired[str | None],
    "opt_crop": bool,
})


CiftiSeparateParameters = typing.TypedDict('CiftiSeparateParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-separate"]],
    "cifti_in": InputPathType,
    "direction": str,
    "volume_all": typing.NotRequired[CiftiSeparateVolumeAllParameters | None],
    "label": typing.NotRequired[list[CiftiSeparateLabelParameters] | None],
    "metric": typing.NotRequired[list[CiftiSeparateMetricParameters] | None],
    "volume": typing.NotRequired[list[CiftiSeparateVolumeParameters] | None],
})
CiftiSeparateParametersTagged = typing.TypedDict('CiftiSeparateParametersTagged', {
    "@type": typing.Literal["workbench/cifti-separate"],
    "cifti_in": InputPathType,
    "direction": str,
    "volume_all": typing.NotRequired[CiftiSeparateVolumeAllParameters | None],
    "label": typing.NotRequired[list[CiftiSeparateLabelParameters] | None],
    "metric": typing.NotRequired[list[CiftiSeparateMetricParameters] | None],
    "volume": typing.NotRequired[list[CiftiSeparateVolumeParameters] | None],
})


class CiftiSeparateVolumeAllOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiSeparateVolumeAllParameters | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""
    opt_roi_roi_out: OutputPathType | None
    """also output the roi of which voxels have data: the roi output volume"""
    opt_label_label_out: OutputPathType | None
    """output a volume label file indicating the location of structures: the
    label output volume"""


def cifti_separate_volume_all_params(
    volume_out: str,
    opt_roi_roi_out: str | None = None,
    opt_label_label_out: str | None = None,
    opt_crop: bool = False,
) -> CiftiSeparateVolumeAllParametersTagged:
    """
    Build parameters.
    
    Args:
        volume_out: the output volume.
        opt_roi_roi_out: also output the roi of which voxels have data: the roi\
            output volume.
        opt_label_label_out: output a volume label file indicating the location\
            of structures: the label output volume.
        opt_crop: crop volume to the size of the data rather than using the\
            original volume size.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "volume_all",
        "volume_out": volume_out,
        "opt_crop": opt_crop,
    }
    if opt_roi_roi_out is not None:
        params["opt_roi_roi_out"] = opt_roi_roi_out
    if opt_label_label_out is not None:
        params["opt_label_label_out"] = opt_label_label_out
    return params


def cifti_separate_volume_all_cargs(
    params: CiftiSeparateVolumeAllParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-volume-all")
    cargs.append(params.get("volume_out", None))
    if params.get("opt_roi_roi_out", None) is not None:
        cargs.extend([
            "-roi",
            params.get("opt_roi_roi_out", None)
        ])
    if params.get("opt_label_label_out", None) is not None:
        cargs.extend([
            "-label",
            params.get("opt_label_label_out", None)
        ])
    if params.get("opt_crop", False):
        cargs.append("-crop")
    return cargs


def cifti_separate_volume_all_outputs(
    params: CiftiSeparateVolumeAllParameters,
    execution: Execution,
) -> CiftiSeparateVolumeAllOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiSeparateVolumeAllOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
        opt_roi_roi_out=execution.output_file(params.get("opt_roi_roi_out", None)) if (params.get("opt_roi_roi_out") is not None) else None,
        opt_label_label_out=execution.output_file(params.get("opt_label_label_out", None)) if (params.get("opt_label_label_out") is not None) else None,
    )
    return ret


class CiftiSeparateLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `list[CiftiSeparateLabelParameters] | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    label_out: OutputPathType
    """the output label file"""
    opt_roi_roi_out: OutputPathType | None
    """also output the roi of which vertices have data: the roi output metric"""


def cifti_separate_label_params(
    structure: str,
    label_out: str,
    opt_roi_roi_out: str | None = None,
) -> CiftiSeparateLabelParametersTagged:
    """
    Build parameters.
    
    Args:
        structure: the structure to output.
        label_out: the output label file.
        opt_roi_roi_out: also output the roi of which vertices have data: the\
            roi output metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "label",
        "structure": structure,
        "label_out": label_out,
    }
    if opt_roi_roi_out is not None:
        params["opt_roi_roi_out"] = opt_roi_roi_out
    return params


def cifti_separate_label_cargs(
    params: CiftiSeparateLabelParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-label")
    cargs.append(params.get("structure", None))
    cargs.append(params.get("label_out", None))
    if params.get("opt_roi_roi_out", None) is not None:
        cargs.extend([
            "-roi",
            params.get("opt_roi_roi_out", None)
        ])
    return cargs


def cifti_separate_label_outputs(
    params: CiftiSeparateLabelParameters,
    execution: Execution,
) -> CiftiSeparateLabelOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiSeparateLabelOutputs(
        root=execution.output_file("."),
        label_out=execution.output_file(params.get("label_out", None)),
        opt_roi_roi_out=execution.output_file(params.get("opt_roi_roi_out", None)) if (params.get("opt_roi_roi_out") is not None) else None,
    )
    return ret


class CiftiSeparateMetricOutputs(typing.NamedTuple):
    """
    Output object returned when calling `list[CiftiSeparateMetricParameters] | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""
    opt_roi_roi_out: OutputPathType | None
    """also output the roi of which vertices have data: the roi output metric"""


def cifti_separate_metric_params(
    structure: str,
    metric_out: str,
    opt_roi_roi_out: str | None = None,
) -> CiftiSeparateMetricParametersTagged:
    """
    Build parameters.
    
    Args:
        structure: the structure to output.
        metric_out: the output metric.
        opt_roi_roi_out: also output the roi of which vertices have data: the\
            roi output metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "metric",
        "structure": structure,
        "metric_out": metric_out,
    }
    if opt_roi_roi_out is not None:
        params["opt_roi_roi_out"] = opt_roi_roi_out
    return params


def cifti_separate_metric_cargs(
    params: CiftiSeparateMetricParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-metric")
    cargs.append(params.get("structure", None))
    cargs.append(params.get("metric_out", None))
    if params.get("opt_roi_roi_out", None) is not None:
        cargs.extend([
            "-roi",
            params.get("opt_roi_roi_out", None)
        ])
    return cargs


def cifti_separate_metric_outputs(
    params: CiftiSeparateMetricParameters,
    execution: Execution,
) -> CiftiSeparateMetricOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiSeparateMetricOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
        opt_roi_roi_out=execution.output_file(params.get("opt_roi_roi_out", None)) if (params.get("opt_roi_roi_out") is not None) else None,
    )
    return ret


class CiftiSeparateVolumeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `list[CiftiSeparateVolumeParameters] | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""
    opt_roi_roi_out: OutputPathType | None
    """also output the roi of which voxels have data: the roi output volume"""


def cifti_separate_volume_params(
    structure: str,
    volume_out: str,
    opt_roi_roi_out: str | None = None,
    opt_crop: bool = False,
) -> CiftiSeparateVolumeParametersTagged:
    """
    Build parameters.
    
    Args:
        structure: the structure to output.
        volume_out: the output volume.
        opt_roi_roi_out: also output the roi of which voxels have data: the roi\
            output volume.
        opt_crop: crop volume to the size of the component rather than using\
            the original volume size.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "volume",
        "structure": structure,
        "volume_out": volume_out,
        "opt_crop": opt_crop,
    }
    if opt_roi_roi_out is not None:
        params["opt_roi_roi_out"] = opt_roi_roi_out
    return params


def cifti_separate_volume_cargs(
    params: CiftiSeparateVolumeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-volume")
    cargs.append(params.get("structure", None))
    cargs.append(params.get("volume_out", None))
    if params.get("opt_roi_roi_out", None) is not None:
        cargs.extend([
            "-roi",
            params.get("opt_roi_roi_out", None)
        ])
    if params.get("opt_crop", False):
        cargs.append("-crop")
    return cargs


def cifti_separate_volume_outputs(
    params: CiftiSeparateVolumeParameters,
    execution: Execution,
) -> CiftiSeparateVolumeOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiSeparateVolumeOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
        opt_roi_roi_out=execution.output_file(params.get("opt_roi_roi_out", None)) if (params.get("opt_roi_roi_out") is not None) else None,
    )
    return ret


class CiftiSeparateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiSeparateParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_all: CiftiSeparateVolumeAllOutputs | None
    """Outputs from `cifti_separate_volume_all_outputs`."""
    label: list[CiftiSeparateLabelOutputs] | None
    """Outputs from `cifti_separate_label_outputs`.This is a list of outputs
    with the same length and order as the inputs."""
    metric: list[CiftiSeparateMetricOutputs] | None
    """Outputs from `cifti_separate_metric_outputs`.This is a list of outputs
    with the same length and order as the inputs."""
    volume: list[CiftiSeparateVolumeOutputs] | None
    """Outputs from `cifti_separate_volume_outputs`.This is a list of outputs
    with the same length and order as the inputs."""


def cifti_separate_params(
    cifti_in: InputPathType,
    direction: str,
    volume_all: CiftiSeparateVolumeAllParameters | None = None,
    label: list[CiftiSeparateLabelParameters] | None = None,
    metric: list[CiftiSeparateMetricParameters] | None = None,
    volume: list[CiftiSeparateVolumeParameters] | None = None,
) -> CiftiSeparateParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the cifti to separate a component of.
        direction: which direction to separate into components, ROW or COLUMN.
        volume_all: separate all volume structures into a volume file.
        label: separate a surface model into a surface label file.
        metric: separate a surface model into a metric file.
        volume: separate a volume structure into a volume file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-separate",
        "cifti_in": cifti_in,
        "direction": direction,
    }
    if volume_all is not None:
        params["volume_all"] = volume_all
    if label is not None:
        params["label"] = label
    if metric is not None:
        params["metric"] = metric
    if volume is not None:
        params["volume"] = volume
    return params


def cifti_separate_cargs(
    params: CiftiSeparateParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-separate")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    cargs.append(params.get("direction", None))
    if params.get("volume_all", None) is not None:
        cargs.extend(cifti_separate_volume_all_cargs(params.get("volume_all", None), execution))
    if params.get("label", None) is not None:
        cargs.extend([a for c in [cifti_separate_label_cargs(s, execution) for s in params.get("label", None)] for a in c])
    if params.get("metric", None) is not None:
        cargs.extend([a for c in [cifti_separate_metric_cargs(s, execution) for s in params.get("metric", None)] for a in c])
    if params.get("volume", None) is not None:
        cargs.extend([a for c in [cifti_separate_volume_cargs(s, execution) for s in params.get("volume", None)] for a in c])
    return cargs


def cifti_separate_outputs(
    params: CiftiSeparateParameters,
    execution: Execution,
) -> CiftiSeparateOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiSeparateOutputs(
        root=execution.output_file("."),
        volume_all=cifti_separate_volume_all_outputs(params.get("volume_all"), execution) if params.get("volume_all") else None,
        label=[cifti_separate_label_outputs(i, execution) if cifti_separate_label_outputs else None for i in params.get("label")] if params.get("label") else None,
        metric=[cifti_separate_metric_outputs(i, execution) if cifti_separate_metric_outputs else None for i in params.get("metric")] if params.get("metric") else None,
        volume=[cifti_separate_volume_outputs(i, execution) if cifti_separate_volume_outputs else None for i in params.get("volume")] if params.get("volume") else None,
    )
    return ret


def cifti_separate_execute(
    params: CiftiSeparateParameters,
    runner: Runner | None = None,
) -> CiftiSeparateOutputs:
    """
    cifti-separate
    
    Write a cifti structure as metric, label or volume.
    
    For dtseries, dscalar, and dlabel, use COLUMN for <direction>, and if you
    have a symmetric dconn, COLUMN is more efficient.
    
    You must specify at least one of -metric, -volume-all, -volume, or -label
    for this command to do anything. Output volumes will spatially line up with
    their original positions, whether or not they are cropped. Volume files
    produced by separating a dlabel file, or from the -label suboption of
    -volume-all, will be label volumes, see -volume-help.
    
    For each <structure> argument, use one of the following strings:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiSeparateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_SEPARATE_METADATA)
    params = execution.params(params)
    cargs = cifti_separate_cargs(params, execution)
    ret = cifti_separate_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_separate(
    cifti_in: InputPathType,
    direction: str,
    volume_all: CiftiSeparateVolumeAllParameters | None = None,
    label: list[CiftiSeparateLabelParameters] | None = None,
    metric: list[CiftiSeparateMetricParameters] | None = None,
    volume: list[CiftiSeparateVolumeParameters] | None = None,
    runner: Runner | None = None,
) -> CiftiSeparateOutputs:
    """
    cifti-separate
    
    Write a cifti structure as metric, label or volume.
    
    For dtseries, dscalar, and dlabel, use COLUMN for <direction>, and if you
    have a symmetric dconn, COLUMN is more efficient.
    
    You must specify at least one of -metric, -volume-all, -volume, or -label
    for this command to do anything. Output volumes will spatially line up with
    their original positions, whether or not they are cropped. Volume files
    produced by separating a dlabel file, or from the -label suboption of
    -volume-all, will be label volumes, see -volume-help.
    
    For each <structure> argument, use one of the following strings:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_in: the cifti to separate a component of.
        direction: which direction to separate into components, ROW or COLUMN.
        volume_all: separate all volume structures into a volume file.
        label: separate a surface model into a surface label file.
        metric: separate a surface model into a metric file.
        volume: separate a volume structure into a volume file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiSeparateOutputs`).
    """
    params = cifti_separate_params(
        cifti_in=cifti_in,
        direction=direction,
        volume_all=volume_all,
        label=label,
        metric=metric,
        volume=volume,
    )
    return cifti_separate_execute(params, runner)


__all__ = [
    "CIFTI_SEPARATE_METADATA",
    "CiftiSeparateLabelOutputs",
    "CiftiSeparateMetricOutputs",
    "CiftiSeparateOutputs",
    "CiftiSeparateVolumeAllOutputs",
    "CiftiSeparateVolumeOutputs",
    "cifti_separate",
    "cifti_separate_execute",
    "cifti_separate_label_params",
    "cifti_separate_metric_params",
    "cifti_separate_params",
    "cifti_separate_volume_all_params",
    "cifti_separate_volume_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

LABEL_TO_BORDER_METADATA = Metadata(
    id="d4004186995df7f49b52041b9843cbc52cd71c97.boutiques",
    name="label-to-border",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


LabelToBorderParameters = typing.TypedDict('LabelToBorderParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/label-to-border"]],
    "surface": InputPathType,
    "label_in": InputPathType,
    "border_out": str,
    "opt_placement_fraction": typing.NotRequired[float | None],
    "opt_column_column": typing.NotRequired[str | None],
})
LabelToBorderParametersTagged = typing.TypedDict('LabelToBorderParametersTagged', {
    "@type": typing.Literal["workbench/label-to-border"],
    "surface": InputPathType,
    "label_in": InputPathType,
    "border_out": str,
    "opt_placement_fraction": typing.NotRequired[float | None],
    "opt_column_column": typing.NotRequired[str | None],
})


class LabelToBorderOutputs(typing.NamedTuple):
    """
    Output object returned when calling `LabelToBorderParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    border_out: OutputPathType
    """the output border file"""


def label_to_border_params(
    surface: InputPathType,
    label_in: InputPathType,
    border_out: str,
    opt_placement_fraction: float | None = None,
    opt_column_column: str | None = None,
) -> LabelToBorderParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to use for neighbor information.
        label_in: the input label file.
        border_out: the output border file.
        opt_placement_fraction: set how far along the edge border points are\
            drawn: fraction along edge from inside vertex (default 0.33).
        opt_column_column: select a single column: the column number or name.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/label-to-border",
        "surface": surface,
        "label_in": label_in,
        "border_out": border_out,
    }
    if opt_placement_fraction is not None:
        params["opt_placement_fraction"] = opt_placement_fraction
    if opt_column_column is not None:
        params["opt_column_column"] = opt_column_column
    return params


def label_to_border_cargs(
    params: LabelToBorderParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-label-to-border")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(execution.input_file(params.get("label_in", None)))
    cargs.append(params.get("border_out", None))
    if params.get("opt_placement_fraction", None) is not None:
        cargs.extend([
            "-placement",
            str(params.get("opt_placement_fraction", None))
        ])
    if params.get("opt_column_column", None) is not None:
        cargs.extend([
            "-column",
            params.get("opt_column_column", None)
        ])
    return cargs


def label_to_border_outputs(
    params: LabelToBorderParameters,
    execution: Execution,
) -> LabelToBorderOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = LabelToBorderOutputs(
        root=execution.output_file("."),
        border_out=execution.output_file(params.get("border_out", None)),
    )
    return ret


def label_to_border_execute(
    params: LabelToBorderParameters,
    runner: Runner | None = None,
) -> LabelToBorderOutputs:
    """
    label-to-border
    
    Draw borders around labels.
    
    For each label, finds all edges on the mesh that cross the boundary of the
    label, and draws borders through them. By default, this is done on all
    columns in the input file, using the map name as the class name for the
    border.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelToBorderOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL_TO_BORDER_METADATA)
    params = execution.params(params)
    cargs = label_to_border_cargs(params, execution)
    ret = label_to_border_outputs(params, execution)
    execution.run(cargs)
    return ret


def label_to_border(
    surface: InputPathType,
    label_in: InputPathType,
    border_out: str,
    opt_placement_fraction: float | None = None,
    opt_column_column: str | None = None,
    runner: Runner | None = None,
) -> LabelToBorderOutputs:
    """
    label-to-border
    
    Draw borders around labels.
    
    For each label, finds all edges on the mesh that cross the boundary of the
    label, and draws borders through them. By default, this is done on all
    columns in the input file, using the map name as the class name for the
    border.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to use for neighbor information.
        label_in: the input label file.
        border_out: the output border file.
        opt_placement_fraction: set how far along the edge border points are\
            drawn: fraction along edge from inside vertex (default 0.33).
        opt_column_column: select a single column: the column number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelToBorderOutputs`).
    """
    params = label_to_border_params(
        surface=surface,
        label_in=label_in,
        border_out=border_out,
        opt_placement_fraction=opt_placement_fraction,
        opt_column_column=opt_column_column,
    )
    return label_to_border_execute(params, runner)


__all__ = [
    "LABEL_TO_BORDER_METADATA",
    "LabelToBorderOutputs",
    "label_to_border",
    "label_to_border_execute",
    "label_to_border_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_CREATE_DENSE_FROM_TEMPLATE_METADATA = Metadata(
    id="11c74fde04f118c37341d938760e0fb6ae8b5218.boutiques",
    name="cifti-create-dense-from-template",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiCreateDenseFromTemplateSeriesParameters = typing.TypedDict('CiftiCreateDenseFromTemplateSeriesParameters', {
    "@type": typing.NotRequired[typing.Literal["series"]],
    "step": float,
    "start": float,
    "opt_unit_unit": typing.NotRequired[str | None],
})
CiftiCreateDenseFromTemplateSeriesParametersTagged = typing.TypedDict('CiftiCreateDenseFromTemplateSeriesParametersTagged', {
    "@type": typing.Literal["series"],
    "step": float,
    "start": float,
    "opt_unit_unit": typing.NotRequired[str | None],
})


CiftiCreateDenseFromTemplateVolumeAllParameters = typing.TypedDict('CiftiCreateDenseFromTemplateVolumeAllParameters', {
    "@type": typing.NotRequired[typing.Literal["volume_all"]],
    "volume_in": InputPathType,
    "opt_from_cropped": bool,
})
CiftiCreateDenseFromTemplateVolumeAllParametersTagged = typing.TypedDict('CiftiCreateDenseFromTemplateVolumeAllParametersTagged', {
    "@type": typing.Literal["volume_all"],
    "volume_in": InputPathType,
    "opt_from_cropped": bool,
})


CiftiCreateDenseFromTemplateCiftiParameters = typing.TypedDict('CiftiCreateDenseFromTemplateCiftiParameters', {
    "@type": typing.NotRequired[typing.Literal["cifti"]],
    "cifti_in": InputPathType,
})
CiftiCreateDenseFromTemplateCiftiParametersTagged = typing.TypedDict('CiftiCreateDenseFromTemplateCiftiParametersTagged', {
    "@type": typing.Literal["cifti"],
    "cifti_in": InputPathType,
})


CiftiCreateDenseFromTemplateMetricParameters = typing.TypedDict('CiftiCreateDenseFromTemplateMetricParameters', {
    "@type": typing.NotRequired[typing.Literal["metric"]],
    "structure": str,
    "metric_in": InputPathType,
})
CiftiCreateDenseFromTemplateMetricParametersTagged = typing.TypedDict('CiftiCreateDenseFromTemplateMetricParametersTagged', {
    "@type": typing.Literal["metric"],
    "structure": str,
    "metric_in": InputPathType,
})


CiftiCreateDenseFromTemplateLabelParameters = typing.TypedDict('CiftiCreateDenseFromTemplateLabelParameters', {
    "@type": typing.NotRequired[typing.Literal["label"]],
    "structure": str,
    "label_in": InputPathType,
})
CiftiCreateDenseFromTemplateLabelParametersTagged = typing.TypedDict('CiftiCreateDenseFromTemplateLabelParametersTagged', {
    "@type": typing.Literal["label"],
    "structure": str,
    "label_in": InputPathType,
})


CiftiCreateDenseFromTemplateVolumeParameters = typing.TypedDict('CiftiCreateDenseFromTemplateVolumeParameters', {
    "@type": typing.NotRequired[typing.Literal["volume"]],
    "structure": str,
    "volume_in": InputPathType,
    "opt_from_cropped": bool,
})
CiftiCreateDenseFromTemplateVolumeParametersTagged = typing.TypedDict('CiftiCreateDenseFromTemplateVolumeParametersTagged', {
    "@type": typing.Literal["volume"],
    "structure": str,
    "volume_in": InputPathType,
    "opt_from_cropped": bool,
})


CiftiCreateDenseFromTemplateParameters = typing.TypedDict('CiftiCreateDenseFromTemplateParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-create-dense-from-template"]],
    "template_cifti": InputPathType,
    "cifti_out": str,
    "series": typing.NotRequired[CiftiCreateDenseFromTemplateSeriesParameters | None],
    "volume_all": typing.NotRequired[CiftiCreateDenseFromTemplateVolumeAllParameters | None],
    "opt_label_collision_action": typing.NotRequired[str | None],
    "cifti": typing.NotRequired[list[CiftiCreateDenseFromTemplateCiftiParameters] | None],
    "metric": typing.NotRequired[list[CiftiCreateDenseFromTemplateMetricParameters] | None],
    "label": typing.NotRequired[list[CiftiCreateDenseFromTemplateLabelParameters] | None],
    "volume": typing.NotRequired[list[CiftiCreateDenseFromTemplateVolumeParameters] | None],
})
CiftiCreateDenseFromTemplateParametersTagged = typing.TypedDict('CiftiCreateDenseFromTemplateParametersTagged', {
    "@type": typing.Literal["workbench/cifti-create-dense-from-template"],
    "template_cifti": InputPathType,
    "cifti_out": str,
    "series": typing.NotRequired[CiftiCreateDenseFromTemplateSeriesParameters | None],
    "volume_all": typing.NotRequired[CiftiCreateDenseFromTemplateVolumeAllParameters | None],
    "opt_label_collision_action": typing.NotRequired[str | None],
    "cifti": typing.NotRequired[list[CiftiCreateDenseFromTemplateCiftiParameters] | None],
    "metric": typing.NotRequired[list[CiftiCreateDenseFromTemplateMetricParameters] | None],
    "label": typing.NotRequired[list[CiftiCreateDenseFromTemplateLabelParameters] | None],
    "volume": typing.NotRequired[list[CiftiCreateDenseFromTemplateVolumeParameters] | None],
})


def cifti_create_dense_from_template_series_params(
    step: float,
    start: float,
    opt_unit_unit: str | None = None,
) -> CiftiCreateDenseFromTemplateSeriesParametersTagged:
    """
    Build parameters.
    
    Args:
        step: increment between series points.
        start: start value of the series.
        opt_unit_unit: select unit for series (default SECOND): unit identifier.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "series",
        "step": step,
        "start": start,
    }
    if opt_unit_unit is not None:
        params["opt_unit_unit"] = opt_unit_unit
    return params


def cifti_create_dense_from_template_series_cargs(
    params: CiftiCreateDenseFromTemplateSeriesParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-series")
    cargs.append(str(params.get("step", None)))
    cargs.append(str(params.get("start", None)))
    if params.get("opt_unit_unit", None) is not None:
        cargs.extend([
            "-unit",
            params.get("opt_unit_unit", None)
        ])
    return cargs


def cifti_create_dense_from_template_volume_all_params(
    volume_in: InputPathType,
    opt_from_cropped: bool = False,
) -> CiftiCreateDenseFromTemplateVolumeAllParametersTagged:
    """
    Build parameters.
    
    Args:
        volume_in: the input volume file.
        opt_from_cropped: the input is cropped to the size of the voxel data in\
            the template file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "volume_all",
        "volume_in": volume_in,
        "opt_from_cropped": opt_from_cropped,
    }
    return params


def cifti_create_dense_from_template_volume_all_cargs(
    params: CiftiCreateDenseFromTemplateVolumeAllParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-volume-all")
    cargs.append(execution.input_file(params.get("volume_in", None)))
    if params.get("opt_from_cropped", False):
        cargs.append("-from-cropped")
    return cargs


def cifti_create_dense_from_template_cifti_params(
    cifti_in: InputPathType,
) -> CiftiCreateDenseFromTemplateCiftiParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: cifti file containing input data.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cifti",
        "cifti_in": cifti_in,
    }
    return params


def cifti_create_dense_from_template_cifti_cargs(
    params: CiftiCreateDenseFromTemplateCiftiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-cifti")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    return cargs


def cifti_create_dense_from_template_metric_params(
    structure: str,
    metric_in: InputPathType,
) -> CiftiCreateDenseFromTemplateMetricParametersTagged:
    """
    Build parameters.
    
    Args:
        structure: which structure to put the metric file into.
        metric_in: input metric file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "metric",
        "structure": structure,
        "metric_in": metric_in,
    }
    return params


def cifti_create_dense_from_template_metric_cargs(
    params: CiftiCreateDenseFromTemplateMetricParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-metric")
    cargs.append(params.get("structure", None))
    cargs.append(execution.input_file(params.get("metric_in", None)))
    return cargs


def cifti_create_dense_from_template_label_params(
    structure: str,
    label_in: InputPathType,
) -> CiftiCreateDenseFromTemplateLabelParametersTagged:
    """
    Build parameters.
    
    Args:
        structure: which structure to put the label file into.
        label_in: input label file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "label",
        "structure": structure,
        "label_in": label_in,
    }
    return params


def cifti_create_dense_from_template_label_cargs(
    params: CiftiCreateDenseFromTemplateLabelParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-label")
    cargs.append(params.get("structure", None))
    cargs.append(execution.input_file(params.get("label_in", None)))
    return cargs


def cifti_create_dense_from_template_volume_params(
    structure: str,
    volume_in: InputPathType,
    opt_from_cropped: bool = False,
) -> CiftiCreateDenseFromTemplateVolumeParametersTagged:
    """
    Build parameters.
    
    Args:
        structure: which structure to put the volume file into.
        volume_in: the input volume file.
        opt_from_cropped: the input is cropped to the size of the volume\
            structure.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "volume",
        "structure": structure,
        "volume_in": volume_in,
        "opt_from_cropped": opt_from_cropped,
    }
    return params


def cifti_create_dense_from_template_volume_cargs(
    params: CiftiCreateDenseFromTemplateVolumeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-volume")
    cargs.append(params.get("structure", None))
    cargs.append(execution.input_file(params.get("volume_in", None)))
    if params.get("opt_from_cropped", False):
        cargs.append("-from-cropped")
    return cargs


class CiftiCreateDenseFromTemplateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiCreateDenseFromTemplateParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_create_dense_from_template_params(
    template_cifti: InputPathType,
    cifti_out: str,
    series: CiftiCreateDenseFromTemplateSeriesParameters | None = None,
    volume_all: CiftiCreateDenseFromTemplateVolumeAllParameters | None = None,
    opt_label_collision_action: str | None = None,
    cifti: list[CiftiCreateDenseFromTemplateCiftiParameters] | None = None,
    metric: list[CiftiCreateDenseFromTemplateMetricParameters] | None = None,
    label: list[CiftiCreateDenseFromTemplateLabelParameters] | None = None,
    volume: list[CiftiCreateDenseFromTemplateVolumeParameters] | None = None,
) -> CiftiCreateDenseFromTemplateParametersTagged:
    """
    Build parameters.
    
    Args:
        template_cifti: file to match brainordinates of.
        cifti_out: the output cifti file.
        series: make a dtseries file instead of a dscalar.
        volume_all: specify an input volume file for all voxel data.
        opt_label_collision_action: how to handle conflicts between label keys:\
            'ERROR', 'SURFACES_FIRST', or 'LEGACY', default 'ERROR', use 'LEGACY'\
            to match v1.4.2 and earlier.
        cifti: use input data from a cifti file.
        metric: use input data from a metric file.
        label: use input data from surface label files.
        volume: use a volume file for a single volume structure's data.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-create-dense-from-template",
        "template_cifti": template_cifti,
        "cifti_out": cifti_out,
    }
    if series is not None:
        params["series"] = series
    if volume_all is not None:
        params["volume_all"] = volume_all
    if opt_label_collision_action is not None:
        params["opt_label_collision_action"] = opt_label_collision_action
    if cifti is not None:
        params["cifti"] = cifti
    if metric is not None:
        params["metric"] = metric
    if label is not None:
        params["label"] = label
    if volume is not None:
        params["volume"] = volume
    return params


def cifti_create_dense_from_template_cargs(
    params: CiftiCreateDenseFromTemplateParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-create-dense-from-template")
    cargs.append(execution.input_file(params.get("template_cifti", None)))
    cargs.append(params.get("cifti_out", None))
    if params.get("series", None) is not None:
        cargs.extend(cifti_create_dense_from_template_series_cargs(params.get("series", None), execution))
    if params.get("volume_all", None) is not None:
        cargs.extend(cifti_create_dense_from_template_volume_all_cargs(params.get("volume_all", None), execution))
    if params.get("opt_label_collision_action", None) is not None:
        cargs.extend([
            "-label-collision",
            params.get("opt_label_collision_action", None)
        ])
    if params.get("cifti", None) is not None:
        cargs.extend([a for c in [cifti_create_dense_from_template_cifti_cargs(s, execution) for s in params.get("cifti", None)] for a in c])
    if params.get("metric", None) is not None:
        cargs.extend([a for c in [cifti_create_dense_from_template_metric_cargs(s, execution) for s in params.get("metric", None)] for a in c])
    if params.get("label", None) is not None:
        cargs.extend([a for c in [cifti_create_dense_from_template_label_cargs(s, execution) for s in params.get("label", None)] for a in c])
    if params.get("volume", None) is not None:
        cargs.extend([a for c in [cifti_create_dense_from_template_volume_cargs(s, execution) for s in params.get("volume", None)] for a in c])
    return cargs


def cifti_create_dense_from_template_outputs(
    params: CiftiCreateDenseFromTemplateParameters,
    execution: Execution,
) -> CiftiCreateDenseFromTemplateOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiCreateDenseFromTemplateOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_create_dense_from_template_execute(
    params: CiftiCreateDenseFromTemplateParameters,
    runner: Runner | None = None,
) -> CiftiCreateDenseFromTemplateOutputs:
    """
    cifti-create-dense-from-template
    
    Create cifti with matching dense map.
    
    This command helps you make a new dscalar, dtseries, or dlabel cifti file
    that matches the brainordinate space used in another cifti file. The
    template file must have the desired brainordinate space in the mapping along
    the column direction (for dtseries, dscalar, dlabel, and symmetric dconn
    this is always the case). All input cifti files must have a brain models
    mapping along column and use the same volume space and/or surface vertex
    count as the template for structures that they contain. If any input files
    contain label data, then input files with non-label data are not allowed,
    and the -series option may not be used.
    
    Any structure that isn't covered by an input is filled with zeros or the
    unlabeled key.
    
    The <structure> argument of -metric, -label or -volume must be one of the
    following:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT
    
    The argument to -unit must be one of the following:
    
    SECOND
    HERTZ
    METER
    RADIAN.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCreateDenseFromTemplateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_CREATE_DENSE_FROM_TEMPLATE_METADATA)
    params = execution.params(params)
    cargs = cifti_create_dense_from_template_cargs(params, execution)
    ret = cifti_create_dense_from_template_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_create_dense_from_template(
    template_cifti: InputPathType,
    cifti_out: str,
    series: CiftiCreateDenseFromTemplateSeriesParameters | None = None,
    volume_all: CiftiCreateDenseFromTemplateVolumeAllParameters | None = None,
    opt_label_collision_action: str | None = None,
    cifti: list[CiftiCreateDenseFromTemplateCiftiParameters] | None = None,
    metric: list[CiftiCreateDenseFromTemplateMetricParameters] | None = None,
    label: list[CiftiCreateDenseFromTemplateLabelParameters] | None = None,
    volume: list[CiftiCreateDenseFromTemplateVolumeParameters] | None = None,
    runner: Runner | None = None,
) -> CiftiCreateDenseFromTemplateOutputs:
    """
    cifti-create-dense-from-template
    
    Create cifti with matching dense map.
    
    This command helps you make a new dscalar, dtseries, or dlabel cifti file
    that matches the brainordinate space used in another cifti file. The
    template file must have the desired brainordinate space in the mapping along
    the column direction (for dtseries, dscalar, dlabel, and symmetric dconn
    this is always the case). All input cifti files must have a brain models
    mapping along column and use the same volume space and/or surface vertex
    count as the template for structures that they contain. If any input files
    contain label data, then input files with non-label data are not allowed,
    and the -series option may not be used.
    
    Any structure that isn't covered by an input is filled with zeros or the
    unlabeled key.
    
    The <structure> argument of -metric, -label or -volume must be one of the
    following:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT
    
    The argument to -unit must be one of the following:
    
    SECOND
    HERTZ
    METER
    RADIAN.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        template_cifti: file to match brainordinates of.
        cifti_out: the output cifti file.
        series: make a dtseries file instead of a dscalar.
        volume_all: specify an input volume file for all voxel data.
        opt_label_collision_action: how to handle conflicts between label keys:\
            'ERROR', 'SURFACES_FIRST', or 'LEGACY', default 'ERROR', use 'LEGACY'\
            to match v1.4.2 and earlier.
        cifti: use input data from a cifti file.
        metric: use input data from a metric file.
        label: use input data from surface label files.
        volume: use a volume file for a single volume structure's data.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCreateDenseFromTemplateOutputs`).
    """
    params = cifti_create_dense_from_template_params(
        template_cifti=template_cifti,
        cifti_out=cifti_out,
        series=series,
        volume_all=volume_all,
        opt_label_collision_action=opt_label_collision_action,
        cifti=cifti,
        metric=metric,
        label=label,
        volume=volume,
    )
    return cifti_create_dense_from_template_execute(params, runner)


__all__ = [
    "CIFTI_CREATE_DENSE_FROM_TEMPLATE_METADATA",
    "CiftiCreateDenseFromTemplateOutputs",
    "cifti_create_dense_from_template",
    "cifti_create_dense_from_template_cifti_params",
    "cifti_create_dense_from_template_execute",
    "cifti_create_dense_from_template_label_params",
    "cifti_create_dense_from_template_metric_params",
    "cifti_create_dense_from_template_params",
    "cifti_create_dense_from_template_series_params",
    "cifti_create_dense_from_template_volume_all_params",
    "cifti_create_dense_from_template_volume_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_LABEL_EXPORT_TABLE_METADATA = Metadata(
    id="8b2a5ebf37ad42d3896a841a48969f292d5ee628.boutiques",
    name="volume-label-export-table",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeLabelExportTableParameters = typing.TypedDict('VolumeLabelExportTableParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-label-export-table"]],
    "label_in": InputPathType,
    "map": str,
    "table_out": str,
})
VolumeLabelExportTableParametersTagged = typing.TypedDict('VolumeLabelExportTableParametersTagged', {
    "@type": typing.Literal["workbench/volume-label-export-table"],
    "label_in": InputPathType,
    "map": str,
    "table_out": str,
})


class VolumeLabelExportTableOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeLabelExportTableParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def volume_label_export_table_params(
    label_in: InputPathType,
    map_: str,
    table_out: str,
) -> VolumeLabelExportTableParametersTagged:
    """
    Build parameters.
    
    Args:
        label_in: the input volume label file.
        map_: the number or name of the label map to use.
        table_out: output - the output text file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-label-export-table",
        "label_in": label_in,
        "map": map_,
        "table_out": table_out,
    }
    return params


def volume_label_export_table_cargs(
    params: VolumeLabelExportTableParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-label-export-table")
    cargs.append(execution.input_file(params.get("label_in", None)))
    cargs.append(params.get("map", None))
    cargs.append(params.get("table_out", None))
    return cargs


def volume_label_export_table_outputs(
    params: VolumeLabelExportTableParameters,
    execution: Execution,
) -> VolumeLabelExportTableOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeLabelExportTableOutputs(
        root=execution.output_file("."),
    )
    return ret


def volume_label_export_table_execute(
    params: VolumeLabelExportTableParameters,
    runner: Runner | None = None,
) -> VolumeLabelExportTableOutputs:
    """
    volume-label-export-table
    
    Export label table from volume as text.
    
    Takes the label table from the volume label map, and writes it to a text
    format matching what is expected by -volume-label-import.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeLabelExportTableOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_LABEL_EXPORT_TABLE_METADATA)
    params = execution.params(params)
    cargs = volume_label_export_table_cargs(params, execution)
    ret = volume_label_export_table_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_label_export_table(
    label_in: InputPathType,
    map_: str,
    table_out: str,
    runner: Runner | None = None,
) -> VolumeLabelExportTableOutputs:
    """
    volume-label-export-table
    
    Export label table from volume as text.
    
    Takes the label table from the volume label map, and writes it to a text
    format matching what is expected by -volume-label-import.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label_in: the input volume label file.
        map_: the number or name of the label map to use.
        table_out: output - the output text file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeLabelExportTableOutputs`).
    """
    params = volume_label_export_table_params(
        label_in=label_in,
        map_=map_,
        table_out=table_out,
    )
    return volume_label_export_table_execute(params, runner)


__all__ = [
    "VOLUME_LABEL_EXPORT_TABLE_METADATA",
    "VolumeLabelExportTableOutputs",
    "volume_label_export_table",
    "volume_label_export_table_execute",
    "volume_label_export_table_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SET_STRUCTURE_METADATA = Metadata(
    id="60f5a5ba046998d47b40d412b42f09c1a0bf64b8.boutiques",
    name="set-structure",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SetStructureParameters = typing.TypedDict('SetStructureParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/set-structure"]],
    "data_file": str,
    "structure": str,
    "opt_surface_type_type": typing.NotRequired[str | None],
    "opt_surface_secondary_type_secondary_type": typing.NotRequired[str | None],
})
SetStructureParametersTagged = typing.TypedDict('SetStructureParametersTagged', {
    "@type": typing.Literal["workbench/set-structure"],
    "data_file": str,
    "structure": str,
    "opt_surface_type_type": typing.NotRequired[str | None],
    "opt_surface_secondary_type_secondary_type": typing.NotRequired[str | None],
})


class SetStructureOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SetStructureParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def set_structure_params(
    data_file: str,
    structure: str,
    opt_surface_type_type: str | None = None,
    opt_surface_secondary_type_secondary_type: str | None = None,
) -> SetStructureParametersTagged:
    """
    Build parameters.
    
    Args:
        data_file: the file to set the structure of.
        structure: the structure to set the file to.
        opt_surface_type_type: set the type of a surface (only used if file is\
            a surface file): name of surface type.
        opt_surface_secondary_type_secondary_type: set the secondary type of a\
            surface (only used if file is a surface file): name of surface\
            secondary type.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/set-structure",
        "data_file": data_file,
        "structure": structure,
    }
    if opt_surface_type_type is not None:
        params["opt_surface_type_type"] = opt_surface_type_type
    if opt_surface_secondary_type_secondary_type is not None:
        params["opt_surface_secondary_type_secondary_type"] = opt_surface_secondary_type_secondary_type
    return params


def set_structure_cargs(
    params: SetStructureParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-set-structure")
    cargs.append(params.get("data_file", None))
    cargs.append(params.get("structure", None))
    if params.get("opt_surface_type_type", None) is not None:
        cargs.extend([
            "-surface-type",
            params.get("opt_surface_type_type", None)
        ])
    if params.get("opt_surface_secondary_type_secondary_type", None) is not None:
        cargs.extend([
            "-surface-secondary-type",
            params.get("opt_surface_secondary_type_secondary_type", None)
        ])
    return cargs


def set_structure_outputs(
    params: SetStructureParameters,
    execution: Execution,
) -> SetStructureOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SetStructureOutputs(
        root=execution.output_file("."),
    )
    return ret


def set_structure_execute(
    params: SetStructureParameters,
    runner: Runner | None = None,
) -> SetStructureOutputs:
    """
    set-structure
    
    Set structure of a data file.
    
    The existing file is modified and rewritten to the same filename. Valid
    values for the structure name are:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT
    
    Valid names for the surface type are:
    
    UNKNOWN
    RECONSTRUCTION
    ANATOMICAL
    INFLATED
    VERY_INFLATED
    SPHERICAL
    SEMI_SPHERICAL
    ELLIPSOID
    FLAT
    HULL
    
    Valid names for the surface secondary type are:
    
    INVALID
    GRAY_WHITE
    MIDTHICKNESS
    PIAL
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SetStructureOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SET_STRUCTURE_METADATA)
    params = execution.params(params)
    cargs = set_structure_cargs(params, execution)
    ret = set_structure_outputs(params, execution)
    execution.run(cargs)
    return ret


def set_structure(
    data_file: str,
    structure: str,
    opt_surface_type_type: str | None = None,
    opt_surface_secondary_type_secondary_type: str | None = None,
    runner: Runner | None = None,
) -> SetStructureOutputs:
    """
    set-structure
    
    Set structure of a data file.
    
    The existing file is modified and rewritten to the same filename. Valid
    values for the structure name are:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT
    
    Valid names for the surface type are:
    
    UNKNOWN
    RECONSTRUCTION
    ANATOMICAL
    INFLATED
    VERY_INFLATED
    SPHERICAL
    SEMI_SPHERICAL
    ELLIPSOID
    FLAT
    HULL
    
    Valid names for the surface secondary type are:
    
    INVALID
    GRAY_WHITE
    MIDTHICKNESS
    PIAL
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        data_file: the file to set the structure of.
        structure: the structure to set the file to.
        opt_surface_type_type: set the type of a surface (only used if file is\
            a surface file): name of surface type.
        opt_surface_secondary_type_secondary_type: set the secondary type of a\
            surface (only used if file is a surface file): name of surface\
            secondary type.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SetStructureOutputs`).
    """
    params = set_structure_params(
        data_file=data_file,
        structure=structure,
        opt_surface_type_type=opt_surface_type_type,
        opt_surface_secondary_type_secondary_type=opt_surface_secondary_type_secondary_type,
    )
    return set_structure_execute(params, runner)


__all__ = [
    "SET_STRUCTURE_METADATA",
    "SetStructureOutputs",
    "set_structure",
    "set_structure_execute",
    "set_structure_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_CORTEX_LAYER_METADATA = Metadata(
    id="0a46e1e069f0f2907566d8c22a87a309eba5009b.boutiques",
    name="surface-cortex-layer",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceCortexLayerParameters = typing.TypedDict('SurfaceCortexLayerParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-cortex-layer"]],
    "white_surface": InputPathType,
    "pial_surface": InputPathType,
    "location": float,
    "out_surface": str,
    "opt_placement_out_placement_metric": typing.NotRequired[str | None],
})
SurfaceCortexLayerParametersTagged = typing.TypedDict('SurfaceCortexLayerParametersTagged', {
    "@type": typing.Literal["workbench/surface-cortex-layer"],
    "white_surface": InputPathType,
    "pial_surface": InputPathType,
    "location": float,
    "out_surface": str,
    "opt_placement_out_placement_metric": typing.NotRequired[str | None],
})


class SurfaceCortexLayerOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceCortexLayerParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_surface: OutputPathType
    """the output surface"""
    opt_placement_out_placement_metric: OutputPathType | None
    """output the placement as a volume fraction from pial to white: output
    metric"""


def surface_cortex_layer_params(
    white_surface: InputPathType,
    pial_surface: InputPathType,
    location: float,
    out_surface: str,
    opt_placement_out_placement_metric: str | None = None,
) -> SurfaceCortexLayerParametersTagged:
    """
    Build parameters.
    
    Args:
        white_surface: the white matter surface.
        pial_surface: the pial surface.
        location: what volume fraction to place the layer at.
        out_surface: the output surface.
        opt_placement_out_placement_metric: output the placement as a volume\
            fraction from pial to white: output metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-cortex-layer",
        "white_surface": white_surface,
        "pial_surface": pial_surface,
        "location": location,
        "out_surface": out_surface,
    }
    if opt_placement_out_placement_metric is not None:
        params["opt_placement_out_placement_metric"] = opt_placement_out_placement_metric
    return params


def surface_cortex_layer_cargs(
    params: SurfaceCortexLayerParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-cortex-layer")
    cargs.append(execution.input_file(params.get("white_surface", None)))
    cargs.append(execution.input_file(params.get("pial_surface", None)))
    cargs.append(str(params.get("location", None)))
    cargs.append(params.get("out_surface", None))
    if params.get("opt_placement_out_placement_metric", None) is not None:
        cargs.extend([
            "-placement-out",
            params.get("opt_placement_out_placement_metric", None)
        ])
    return cargs


def surface_cortex_layer_outputs(
    params: SurfaceCortexLayerParameters,
    execution: Execution,
) -> SurfaceCortexLayerOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceCortexLayerOutputs(
        root=execution.output_file("."),
        out_surface=execution.output_file(params.get("out_surface", None)),
        opt_placement_out_placement_metric=execution.output_file(params.get("opt_placement_out_placement_metric", None)) if (params.get("opt_placement_out_placement_metric") is not None) else None,
    )
    return ret


def surface_cortex_layer_execute(
    params: SurfaceCortexLayerParameters,
    runner: Runner | None = None,
) -> SurfaceCortexLayerOutputs:
    """
    surface-cortex-layer
    
    Create surface approximating a cortical layer.
    
    The input surfaces must have vertex correspondence. The output surface is
    generated by placing vertices between the two surfaces such that the
    enclosed volume within any small patch of the new and white surfaces is the
    given fraction of the volume of the same patch between the pial and white
    surfaces (i.e., specifying 0 would give the white surface, 1 would give the
    pial surface). .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceCortexLayerOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_CORTEX_LAYER_METADATA)
    params = execution.params(params)
    cargs = surface_cortex_layer_cargs(params, execution)
    ret = surface_cortex_layer_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_cortex_layer(
    white_surface: InputPathType,
    pial_surface: InputPathType,
    location: float,
    out_surface: str,
    opt_placement_out_placement_metric: str | None = None,
    runner: Runner | None = None,
) -> SurfaceCortexLayerOutputs:
    """
    surface-cortex-layer
    
    Create surface approximating a cortical layer.
    
    The input surfaces must have vertex correspondence. The output surface is
    generated by placing vertices between the two surfaces such that the
    enclosed volume within any small patch of the new and white surfaces is the
    given fraction of the volume of the same patch between the pial and white
    surfaces (i.e., specifying 0 would give the white surface, 1 would give the
    pial surface). .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        white_surface: the white matter surface.
        pial_surface: the pial surface.
        location: what volume fraction to place the layer at.
        out_surface: the output surface.
        opt_placement_out_placement_metric: output the placement as a volume\
            fraction from pial to white: output metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceCortexLayerOutputs`).
    """
    params = surface_cortex_layer_params(
        white_surface=white_surface,
        pial_surface=pial_surface,
        location=location,
        out_surface=out_surface,
        opt_placement_out_placement_metric=opt_placement_out_placement_metric,
    )
    return surface_cortex_layer_execute(params, runner)


__all__ = [
    "SURFACE_CORTEX_LAYER_METADATA",
    "SurfaceCortexLayerOutputs",
    "surface_cortex_layer",
    "surface_cortex_layer_execute",
    "surface_cortex_layer_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_CROSS_CORRELATION_METADATA = Metadata(
    id="05c0db0d9a53210f00f60734da04cd0863715c7a.boutiques",
    name="cifti-cross-correlation",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiCrossCorrelationParameters = typing.TypedDict('CiftiCrossCorrelationParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-cross-correlation"]],
    "cifti_a": InputPathType,
    "cifti_b": InputPathType,
    "cifti_out": str,
    "opt_weights_weight_file": typing.NotRequired[str | None],
    "opt_fisher_z": bool,
    "opt_mem_limit_limit_gb": typing.NotRequired[float | None],
})
CiftiCrossCorrelationParametersTagged = typing.TypedDict('CiftiCrossCorrelationParametersTagged', {
    "@type": typing.Literal["workbench/cifti-cross-correlation"],
    "cifti_a": InputPathType,
    "cifti_b": InputPathType,
    "cifti_out": str,
    "opt_weights_weight_file": typing.NotRequired[str | None],
    "opt_fisher_z": bool,
    "opt_mem_limit_limit_gb": typing.NotRequired[float | None],
})


class CiftiCrossCorrelationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiCrossCorrelationParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """output cifti file"""


def cifti_cross_correlation_params(
    cifti_a: InputPathType,
    cifti_b: InputPathType,
    cifti_out: str,
    opt_weights_weight_file: str | None = None,
    opt_fisher_z: bool = False,
    opt_mem_limit_limit_gb: float | None = None,
) -> CiftiCrossCorrelationParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_a: first input cifti file.
        cifti_b: second input cifti file.
        cifti_out: output cifti file.
        opt_weights_weight_file: specify column weights: text file containing\
            one weight per column.
        opt_fisher_z: apply fisher small z transform (ie, artanh) to\
            correlation.
        opt_mem_limit_limit_gb: restrict memory usage: memory limit in\
            gigabytes.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-cross-correlation",
        "cifti_a": cifti_a,
        "cifti_b": cifti_b,
        "cifti_out": cifti_out,
        "opt_fisher_z": opt_fisher_z,
    }
    if opt_weights_weight_file is not None:
        params["opt_weights_weight_file"] = opt_weights_weight_file
    if opt_mem_limit_limit_gb is not None:
        params["opt_mem_limit_limit_gb"] = opt_mem_limit_limit_gb
    return params


def cifti_cross_correlation_cargs(
    params: CiftiCrossCorrelationParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-cross-correlation")
    cargs.append(execution.input_file(params.get("cifti_a", None)))
    cargs.append(execution.input_file(params.get("cifti_b", None)))
    cargs.append(params.get("cifti_out", None))
    if params.get("opt_weights_weight_file", None) is not None:
        cargs.extend([
            "-weights",
            params.get("opt_weights_weight_file", None)
        ])
    if params.get("opt_fisher_z", False):
        cargs.append("-fisher-z")
    if params.get("opt_mem_limit_limit_gb", None) is not None:
        cargs.extend([
            "-mem-limit",
            str(params.get("opt_mem_limit_limit_gb", None))
        ])
    return cargs


def cifti_cross_correlation_outputs(
    params: CiftiCrossCorrelationParameters,
    execution: Execution,
) -> CiftiCrossCorrelationOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiCrossCorrelationOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_cross_correlation_execute(
    params: CiftiCrossCorrelationParameters,
    runner: Runner | None = None,
) -> CiftiCrossCorrelationOutputs:
    """
    cifti-cross-correlation
    
    Correlate a cifti file with another cifti file.
    
    Correlates every row in <cifti-a> with every row in <cifti-b>. The mapping
    along columns in <cifti-b> becomes the mapping along rows in the output.
    
    When using the -fisher-z option, the output is NOT a Z-score, it is
    artanh(r), to do further math on this output, consider using -cifti-math.
    
    Restricting the memory usage will make it calculate the output in chunks, by
    reading through <cifti-b> multiple times.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCrossCorrelationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_CROSS_CORRELATION_METADATA)
    params = execution.params(params)
    cargs = cifti_cross_correlation_cargs(params, execution)
    ret = cifti_cross_correlation_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_cross_correlation(
    cifti_a: InputPathType,
    cifti_b: InputPathType,
    cifti_out: str,
    opt_weights_weight_file: str | None = None,
    opt_fisher_z: bool = False,
    opt_mem_limit_limit_gb: float | None = None,
    runner: Runner | None = None,
) -> CiftiCrossCorrelationOutputs:
    """
    cifti-cross-correlation
    
    Correlate a cifti file with another cifti file.
    
    Correlates every row in <cifti-a> with every row in <cifti-b>. The mapping
    along columns in <cifti-b> becomes the mapping along rows in the output.
    
    When using the -fisher-z option, the output is NOT a Z-score, it is
    artanh(r), to do further math on this output, consider using -cifti-math.
    
    Restricting the memory usage will make it calculate the output in chunks, by
    reading through <cifti-b> multiple times.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_a: first input cifti file.
        cifti_b: second input cifti file.
        cifti_out: output cifti file.
        opt_weights_weight_file: specify column weights: text file containing\
            one weight per column.
        opt_fisher_z: apply fisher small z transform (ie, artanh) to\
            correlation.
        opt_mem_limit_limit_gb: restrict memory usage: memory limit in\
            gigabytes.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCrossCorrelationOutputs`).
    """
    params = cifti_cross_correlation_params(
        cifti_a=cifti_a,
        cifti_b=cifti_b,
        cifti_out=cifti_out,
        opt_weights_weight_file=opt_weights_weight_file,
        opt_fisher_z=opt_fisher_z,
        opt_mem_limit_limit_gb=opt_mem_limit_limit_gb,
    )
    return cifti_cross_correlation_execute(params, runner)


__all__ = [
    "CIFTI_CROSS_CORRELATION_METADATA",
    "CiftiCrossCorrelationOutputs",
    "cifti_cross_correlation",
    "cifti_cross_correlation_execute",
    "cifti_cross_correlation_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_APPLY_WARPFIELD_METADATA = Metadata(
    id="6a441ba1d393e5ce7c0331880f44291c415f3d62.boutiques",
    name="surface-apply-warpfield",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceApplyWarpfieldParameters = typing.TypedDict('SurfaceApplyWarpfieldParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-apply-warpfield"]],
    "in_surf": InputPathType,
    "warpfield": str,
    "out_surf": str,
    "opt_fnirt_forward_warp": typing.NotRequired[str | None],
})
SurfaceApplyWarpfieldParametersTagged = typing.TypedDict('SurfaceApplyWarpfieldParametersTagged', {
    "@type": typing.Literal["workbench/surface-apply-warpfield"],
    "in_surf": InputPathType,
    "warpfield": str,
    "out_surf": str,
    "opt_fnirt_forward_warp": typing.NotRequired[str | None],
})


class SurfaceApplyWarpfieldOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceApplyWarpfieldParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_surf: OutputPathType
    """the output transformed surface"""


def surface_apply_warpfield_params(
    in_surf: InputPathType,
    warpfield: str,
    out_surf: str,
    opt_fnirt_forward_warp: str | None = None,
) -> SurfaceApplyWarpfieldParametersTagged:
    """
    Build parameters.
    
    Args:
        in_surf: the surface to transform.
        warpfield: the INVERSE warpfield.
        out_surf: the output transformed surface.
        opt_fnirt_forward_warp: MUST be used if using a fnirt warpfield: the\
            forward warpfield.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-apply-warpfield",
        "in_surf": in_surf,
        "warpfield": warpfield,
        "out_surf": out_surf,
    }
    if opt_fnirt_forward_warp is not None:
        params["opt_fnirt_forward_warp"] = opt_fnirt_forward_warp
    return params


def surface_apply_warpfield_cargs(
    params: SurfaceApplyWarpfieldParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-apply-warpfield")
    cargs.append(execution.input_file(params.get("in_surf", None)))
    cargs.append(params.get("warpfield", None))
    cargs.append(params.get("out_surf", None))
    if params.get("opt_fnirt_forward_warp", None) is not None:
        cargs.extend([
            "-fnirt",
            params.get("opt_fnirt_forward_warp", None)
        ])
    return cargs


def surface_apply_warpfield_outputs(
    params: SurfaceApplyWarpfieldParameters,
    execution: Execution,
) -> SurfaceApplyWarpfieldOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceApplyWarpfieldOutputs(
        root=execution.output_file("."),
        out_surf=execution.output_file(params.get("out_surf", None)),
    )
    return ret


def surface_apply_warpfield_execute(
    params: SurfaceApplyWarpfieldParameters,
    runner: Runner | None = None,
) -> SurfaceApplyWarpfieldOutputs:
    """
    surface-apply-warpfield
    
    Apply warpfield to surface file.
    
    NOTE: warping a surface requires the INVERSE of the warpfield used to warp
    the volume it lines up with. The header of the forward warp is needed by the
    -fnirt option in order to correctly interpret the displacements in the fnirt
    warpfield.
    
    If the -fnirt option is not present, the warpfield must be a nifti 'world'
    warpfield, which can be obtained with the -convert-warpfield command.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceApplyWarpfieldOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_APPLY_WARPFIELD_METADATA)
    params = execution.params(params)
    cargs = surface_apply_warpfield_cargs(params, execution)
    ret = surface_apply_warpfield_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_apply_warpfield(
    in_surf: InputPathType,
    warpfield: str,
    out_surf: str,
    opt_fnirt_forward_warp: str | None = None,
    runner: Runner | None = None,
) -> SurfaceApplyWarpfieldOutputs:
    """
    surface-apply-warpfield
    
    Apply warpfield to surface file.
    
    NOTE: warping a surface requires the INVERSE of the warpfield used to warp
    the volume it lines up with. The header of the forward warp is needed by the
    -fnirt option in order to correctly interpret the displacements in the fnirt
    warpfield.
    
    If the -fnirt option is not present, the warpfield must be a nifti 'world'
    warpfield, which can be obtained with the -convert-warpfield command.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        in_surf: the surface to transform.
        warpfield: the INVERSE warpfield.
        out_surf: the output transformed surface.
        opt_fnirt_forward_warp: MUST be used if using a fnirt warpfield: the\
            forward warpfield.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceApplyWarpfieldOutputs`).
    """
    params = surface_apply_warpfield_params(
        in_surf=in_surf,
        warpfield=warpfield,
        out_surf=out_surf,
        opt_fnirt_forward_warp=opt_fnirt_forward_warp,
    )
    return surface_apply_warpfield_execute(params, runner)


__all__ = [
    "SURFACE_APPLY_WARPFIELD_METADATA",
    "SurfaceApplyWarpfieldOutputs",
    "surface_apply_warpfield",
    "surface_apply_warpfield_execute",
    "surface_apply_warpfield_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

METRIC_REDUCE_METADATA = Metadata(
    id="1d37ac901662d6962e04b6b12face19d11c30fc5.boutiques",
    name="metric-reduce",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


MetricReduceExcludeOutliersParameters = typing.TypedDict('MetricReduceExcludeOutliersParameters', {
    "@type": typing.NotRequired[typing.Literal["exclude_outliers"]],
    "sigma_below": float,
    "sigma_above": float,
})
MetricReduceExcludeOutliersParametersTagged = typing.TypedDict('MetricReduceExcludeOutliersParametersTagged', {
    "@type": typing.Literal["exclude_outliers"],
    "sigma_below": float,
    "sigma_above": float,
})


MetricReduceParameters = typing.TypedDict('MetricReduceParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/metric-reduce"]],
    "metric_in": InputPathType,
    "operation": str,
    "metric_out": str,
    "exclude_outliers": typing.NotRequired[MetricReduceExcludeOutliersParameters | None],
    "opt_only_numeric": bool,
})
MetricReduceParametersTagged = typing.TypedDict('MetricReduceParametersTagged', {
    "@type": typing.Literal["workbench/metric-reduce"],
    "metric_in": InputPathType,
    "operation": str,
    "metric_out": str,
    "exclude_outliers": typing.NotRequired[MetricReduceExcludeOutliersParameters | None],
    "opt_only_numeric": bool,
})


def metric_reduce_exclude_outliers_params(
    sigma_below: float,
    sigma_above: float,
) -> MetricReduceExcludeOutliersParametersTagged:
    """
    Build parameters.
    
    Args:
        sigma_below: number of standard deviations below the mean to include.
        sigma_above: number of standard deviations above the mean to include.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "exclude_outliers",
        "sigma_below": sigma_below,
        "sigma_above": sigma_above,
    }
    return params


def metric_reduce_exclude_outliers_cargs(
    params: MetricReduceExcludeOutliersParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-exclude-outliers")
    cargs.append(str(params.get("sigma_below", None)))
    cargs.append(str(params.get("sigma_above", None)))
    return cargs


class MetricReduceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricReduceParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def metric_reduce_params(
    metric_in: InputPathType,
    operation: str,
    metric_out: str,
    exclude_outliers: MetricReduceExcludeOutliersParameters | None = None,
    opt_only_numeric: bool = False,
) -> MetricReduceParametersTagged:
    """
    Build parameters.
    
    Args:
        metric_in: the metric to reduce.
        operation: the reduction operator to use.
        metric_out: the output metric.
        exclude_outliers: exclude non-numeric values and outliers by standard\
            deviation.
        opt_only_numeric: exclude non-numeric values.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/metric-reduce",
        "metric_in": metric_in,
        "operation": operation,
        "metric_out": metric_out,
        "opt_only_numeric": opt_only_numeric,
    }
    if exclude_outliers is not None:
        params["exclude_outliers"] = exclude_outliers
    return params


def metric_reduce_cargs(
    params: MetricReduceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-reduce")
    cargs.append(execution.input_file(params.get("metric_in", None)))
    cargs.append(params.get("operation", None))
    cargs.append(params.get("metric_out", None))
    if params.get("exclude_outliers", None) is not None:
        cargs.extend(metric_reduce_exclude_outliers_cargs(params.get("exclude_outliers", None), execution))
    if params.get("opt_only_numeric", False):
        cargs.append("-only-numeric")
    return cargs


def metric_reduce_outputs(
    params: MetricReduceParameters,
    execution: Execution,
) -> MetricReduceOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetricReduceOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def metric_reduce_execute(
    params: MetricReduceParameters,
    runner: Runner | None = None,
) -> MetricReduceOutputs:
    """
    metric-reduce
    
    Perform reduction operation across metric columns.
    
    For each surface vertex, takes the data across columns as a vector, and
    performs the specified reduction on it, putting the result into the single
    output column at that vertex. The reduction operators are as follows:
    
    MAX: the maximum value
    MIN: the minimum value
    INDEXMAX: the 1-based index of the maximum value
    INDEXMIN: the 1-based index of the minimum value
    SUM: add all values
    PRODUCT: multiply all values
    MEAN: the mean of the data
    STDEV: the standard deviation (N denominator)
    SAMPSTDEV: the sample standard deviation (N-1 denominator)
    VARIANCE: the variance of the data
    TSNR: mean divided by sample standard deviation (N-1 denominator)
    COV: sample standard deviation (N-1 denominator) divided by mean
    L2NORM: square root of sum of squares
    MEDIAN: the median of the data
    MODE: the mode of the data
    COUNT_NONZERO: the number of nonzero elements in the data
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricReduceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_REDUCE_METADATA)
    params = execution.params(params)
    cargs = metric_reduce_cargs(params, execution)
    ret = metric_reduce_outputs(params, execution)
    execution.run(cargs)
    return ret


def metric_reduce(
    metric_in: InputPathType,
    operation: str,
    metric_out: str,
    exclude_outliers: MetricReduceExcludeOutliersParameters | None = None,
    opt_only_numeric: bool = False,
    runner: Runner | None = None,
) -> MetricReduceOutputs:
    """
    metric-reduce
    
    Perform reduction operation across metric columns.
    
    For each surface vertex, takes the data across columns as a vector, and
    performs the specified reduction on it, putting the result into the single
    output column at that vertex. The reduction operators are as follows:
    
    MAX: the maximum value
    MIN: the minimum value
    INDEXMAX: the 1-based index of the maximum value
    INDEXMIN: the 1-based index of the minimum value
    SUM: add all values
    PRODUCT: multiply all values
    MEAN: the mean of the data
    STDEV: the standard deviation (N denominator)
    SAMPSTDEV: the sample standard deviation (N-1 denominator)
    VARIANCE: the variance of the data
    TSNR: mean divided by sample standard deviation (N-1 denominator)
    COV: sample standard deviation (N-1 denominator) divided by mean
    L2NORM: square root of sum of squares
    MEDIAN: the median of the data
    MODE: the mode of the data
    COUNT_NONZERO: the number of nonzero elements in the data
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        metric_in: the metric to reduce.
        operation: the reduction operator to use.
        metric_out: the output metric.
        exclude_outliers: exclude non-numeric values and outliers by standard\
            deviation.
        opt_only_numeric: exclude non-numeric values.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricReduceOutputs`).
    """
    params = metric_reduce_params(
        metric_in=metric_in,
        operation=operation,
        metric_out=metric_out,
        exclude_outliers=exclude_outliers,
        opt_only_numeric=opt_only_numeric,
    )
    return metric_reduce_execute(params, runner)


__all__ = [
    "METRIC_REDUCE_METADATA",
    "MetricReduceOutputs",
    "metric_reduce",
    "metric_reduce_exclude_outliers_params",
    "metric_reduce_execute",
    "metric_reduce_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_GEODESIC_DISTANCE_ALL_TO_ALL_METADATA = Metadata(
    id="7198c6400471913047c2af5e7257561969e48b2a.boutiques",
    name="surface-geodesic-distance-all-to-all",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceGeodesicDistanceAllToAllParameters = typing.TypedDict('SurfaceGeodesicDistanceAllToAllParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-geodesic-distance-all-to-all"]],
    "surface": InputPathType,
    "cifti_out": str,
    "opt_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_limit_limit_mm": typing.NotRequired[float | None],
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
    "opt_naive": bool,
})
SurfaceGeodesicDistanceAllToAllParametersTagged = typing.TypedDict('SurfaceGeodesicDistanceAllToAllParametersTagged', {
    "@type": typing.Literal["workbench/surface-geodesic-distance-all-to-all"],
    "surface": InputPathType,
    "cifti_out": str,
    "opt_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_limit_limit_mm": typing.NotRequired[float | None],
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
    "opt_naive": bool,
})


class SurfaceGeodesicDistanceAllToAllOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceGeodesicDistanceAllToAllParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """single-hemisphere dconn containing the distances"""


def surface_geodesic_distance_all_to_all_params(
    surface: InputPathType,
    cifti_out: str,
    opt_roi_roi_metric: InputPathType | None = None,
    opt_limit_limit_mm: float | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    opt_naive: bool = False,
) -> SurfaceGeodesicDistanceAllToAllParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to compute on.
        cifti_out: single-hemisphere dconn containing the distances.
        opt_roi_roi_metric: only output distances for vertices inside an ROI:\
            the ROI as a metric file.
        opt_limit_limit_mm: stop at a specified distance: distance in mm to\
            stop at.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        opt_naive: use only neighbors, don't crawl triangles (not recommended).
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-geodesic-distance-all-to-all",
        "surface": surface,
        "cifti_out": cifti_out,
        "opt_naive": opt_naive,
    }
    if opt_roi_roi_metric is not None:
        params["opt_roi_roi_metric"] = opt_roi_roi_metric
    if opt_limit_limit_mm is not None:
        params["opt_limit_limit_mm"] = opt_limit_limit_mm
    if opt_corrected_areas_area_metric is not None:
        params["opt_corrected_areas_area_metric"] = opt_corrected_areas_area_metric
    return params


def surface_geodesic_distance_all_to_all_cargs(
    params: SurfaceGeodesicDistanceAllToAllParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-geodesic-distance-all-to-all")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(params.get("cifti_out", None))
    if params.get("opt_roi_roi_metric", None) is not None:
        cargs.extend([
            "-roi",
            execution.input_file(params.get("opt_roi_roi_metric", None))
        ])
    if params.get("opt_limit_limit_mm", None) is not None:
        cargs.extend([
            "-limit",
            str(params.get("opt_limit_limit_mm", None))
        ])
    if params.get("opt_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(params.get("opt_corrected_areas_area_metric", None))
        ])
    if params.get("opt_naive", False):
        cargs.append("-naive")
    return cargs


def surface_geodesic_distance_all_to_all_outputs(
    params: SurfaceGeodesicDistanceAllToAllParameters,
    execution: Execution,
) -> SurfaceGeodesicDistanceAllToAllOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceGeodesicDistanceAllToAllOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def surface_geodesic_distance_all_to_all_execute(
    params: SurfaceGeodesicDistanceAllToAllParameters,
    runner: Runner | None = None,
) -> SurfaceGeodesicDistanceAllToAllOutputs:
    """
    surface-geodesic-distance-all-to-all
    
    Compute geodesic distances from all vertices.
    
    Computes geodesic distance from every vertex to every vertex, outputting a
    single-hemisphere dconn file. If you are only interested in a few vertices,
    see -surface-geodesic-distance. When -limit is specified, any vertex beyond
    the limit is assigned the value -1.
    
    The -roi option makes the output file smaller by not outputting distances to
    or from vertices outside the ROI, but paths are still allowed to go outside
    the ROI when finding distances to other vertices.
    
    The -corrected-areas option should be used when the input is a group average
    surface - group average surfaces have significantly less surface area than
    individual surfaces do, and therefore distances measured on them would be
    smaller than measuring them on individual surfaces. In this case, the input
    to this option should be a group average of the output of
    -surface-vertex-areas for each subject.
    
    If -naive is not specified, the algorithm uses not just immediate neighbors,
    but also neighbors derived from crawling across pairs of triangles that
    share an edge.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceGeodesicDistanceAllToAllOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_GEODESIC_DISTANCE_ALL_TO_ALL_METADATA)
    params = execution.params(params)
    cargs = surface_geodesic_distance_all_to_all_cargs(params, execution)
    ret = surface_geodesic_distance_all_to_all_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_geodesic_distance_all_to_all(
    surface: InputPathType,
    cifti_out: str,
    opt_roi_roi_metric: InputPathType | None = None,
    opt_limit_limit_mm: float | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    opt_naive: bool = False,
    runner: Runner | None = None,
) -> SurfaceGeodesicDistanceAllToAllOutputs:
    """
    surface-geodesic-distance-all-to-all
    
    Compute geodesic distances from all vertices.
    
    Computes geodesic distance from every vertex to every vertex, outputting a
    single-hemisphere dconn file. If you are only interested in a few vertices,
    see -surface-geodesic-distance. When -limit is specified, any vertex beyond
    the limit is assigned the value -1.
    
    The -roi option makes the output file smaller by not outputting distances to
    or from vertices outside the ROI, but paths are still allowed to go outside
    the ROI when finding distances to other vertices.
    
    The -corrected-areas option should be used when the input is a group average
    surface - group average surfaces have significantly less surface area than
    individual surfaces do, and therefore distances measured on them would be
    smaller than measuring them on individual surfaces. In this case, the input
    to this option should be a group average of the output of
    -surface-vertex-areas for each subject.
    
    If -naive is not specified, the algorithm uses not just immediate neighbors,
    but also neighbors derived from crawling across pairs of triangles that
    share an edge.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to compute on.
        cifti_out: single-hemisphere dconn containing the distances.
        opt_roi_roi_metric: only output distances for vertices inside an ROI:\
            the ROI as a metric file.
        opt_limit_limit_mm: stop at a specified distance: distance in mm to\
            stop at.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        opt_naive: use only neighbors, don't crawl triangles (not recommended).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceGeodesicDistanceAllToAllOutputs`).
    """
    params = surface_geodesic_distance_all_to_all_params(
        surface=surface,
        cifti_out=cifti_out,
        opt_roi_roi_metric=opt_roi_roi_metric,
        opt_limit_limit_mm=opt_limit_limit_mm,
        opt_corrected_areas_area_metric=opt_corrected_areas_area_metric,
        opt_naive=opt_naive,
    )
    return surface_geodesic_distance_all_to_all_execute(params, runner)


__all__ = [
    "SURFACE_GEODESIC_DISTANCE_ALL_TO_ALL_METADATA",
    "SurfaceGeodesicDistanceAllToAllOutputs",
    "surface_geodesic_distance_all_to_all",
    "surface_geodesic_distance_all_to_all_execute",
    "surface_geodesic_distance_all_to_all_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_PARCEL_MAPPING_TO_LABEL_METADATA = Metadata(
    id="0bf15c8c4c3f06d434147770f8cfca4d5d152ae9.boutiques",
    name="cifti-parcel-mapping-to-label",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiParcelMappingToLabelParameters = typing.TypedDict('CiftiParcelMappingToLabelParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-parcel-mapping-to-label"]],
    "cifti_in": InputPathType,
    "direction": str,
    "template_cifti": InputPathType,
    "dlabel_out": str,
})
CiftiParcelMappingToLabelParametersTagged = typing.TypedDict('CiftiParcelMappingToLabelParametersTagged', {
    "@type": typing.Literal["workbench/cifti-parcel-mapping-to-label"],
    "cifti_in": InputPathType,
    "direction": str,
    "template_cifti": InputPathType,
    "dlabel_out": str,
})


class CiftiParcelMappingToLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiParcelMappingToLabelParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    dlabel_out: OutputPathType
    """the output dense label file"""


def cifti_parcel_mapping_to_label_params(
    cifti_in: InputPathType,
    direction: str,
    template_cifti: InputPathType,
    dlabel_out: str,
) -> CiftiParcelMappingToLabelParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the input parcellated file.
        direction: which dimension to take the parcel map from, ROW or COLUMN.
        template_cifti: a cifti file with the desired dense mapping along\
            column.
        dlabel_out: the output dense label file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-parcel-mapping-to-label",
        "cifti_in": cifti_in,
        "direction": direction,
        "template_cifti": template_cifti,
        "dlabel_out": dlabel_out,
    }
    return params


def cifti_parcel_mapping_to_label_cargs(
    params: CiftiParcelMappingToLabelParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-parcel-mapping-to-label")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    cargs.append(params.get("direction", None))
    cargs.append(execution.input_file(params.get("template_cifti", None)))
    cargs.append(params.get("dlabel_out", None))
    return cargs


def cifti_parcel_mapping_to_label_outputs(
    params: CiftiParcelMappingToLabelParameters,
    execution: Execution,
) -> CiftiParcelMappingToLabelOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiParcelMappingToLabelOutputs(
        root=execution.output_file("."),
        dlabel_out=execution.output_file(params.get("dlabel_out", None)),
    )
    return ret


def cifti_parcel_mapping_to_label_execute(
    params: CiftiParcelMappingToLabelParameters,
    runner: Runner | None = None,
) -> CiftiParcelMappingToLabelOutputs:
    """
    cifti-parcel-mapping-to-label
    
    Create dlabel from parcellated file.
    
    This command will output a dlabel file, useful for doing the same
    parcellation to another dense file.
    
    For ptseries, pscalar, plabel, pconn, and pdconn, using COLUMN for
    <direction> will work.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiParcelMappingToLabelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_PARCEL_MAPPING_TO_LABEL_METADATA)
    params = execution.params(params)
    cargs = cifti_parcel_mapping_to_label_cargs(params, execution)
    ret = cifti_parcel_mapping_to_label_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_parcel_mapping_to_label(
    cifti_in: InputPathType,
    direction: str,
    template_cifti: InputPathType,
    dlabel_out: str,
    runner: Runner | None = None,
) -> CiftiParcelMappingToLabelOutputs:
    """
    cifti-parcel-mapping-to-label
    
    Create dlabel from parcellated file.
    
    This command will output a dlabel file, useful for doing the same
    parcellation to another dense file.
    
    For ptseries, pscalar, plabel, pconn, and pdconn, using COLUMN for
    <direction> will work.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_in: the input parcellated file.
        direction: which dimension to take the parcel map from, ROW or COLUMN.
        template_cifti: a cifti file with the desired dense mapping along\
            column.
        dlabel_out: the output dense label file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiParcelMappingToLabelOutputs`).
    """
    params = cifti_parcel_mapping_to_label_params(
        cifti_in=cifti_in,
        direction=direction,
        template_cifti=template_cifti,
        dlabel_out=dlabel_out,
    )
    return cifti_parcel_mapping_to_label_execute(params, runner)


__all__ = [
    "CIFTI_PARCEL_MAPPING_TO_LABEL_METADATA",
    "CiftiParcelMappingToLabelOutputs",
    "cifti_parcel_mapping_to_label",
    "cifti_parcel_mapping_to_label_execute",
    "cifti_parcel_mapping_to_label_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

BORDER_EXPORT_COLOR_TABLE_METADATA = Metadata(
    id="c4fae465526913da9084677d6ed578ea3f03a993.boutiques",
    name="border-export-color-table",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


BorderExportColorTableParameters = typing.TypedDict('BorderExportColorTableParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/border-export-color-table"]],
    "border_file": InputPathType,
    "table_out": str,
    "opt_class_colors": bool,
})
BorderExportColorTableParametersTagged = typing.TypedDict('BorderExportColorTableParametersTagged', {
    "@type": typing.Literal["workbench/border-export-color-table"],
    "border_file": InputPathType,
    "table_out": str,
    "opt_class_colors": bool,
})


class BorderExportColorTableOutputs(typing.NamedTuple):
    """
    Output object returned when calling `BorderExportColorTableParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def border_export_color_table_params(
    border_file: InputPathType,
    table_out: str,
    opt_class_colors: bool = False,
) -> BorderExportColorTableParametersTagged:
    """
    Build parameters.
    
    Args:
        border_file: the input border file.
        table_out: output - the output text file.
        opt_class_colors: use class colors instead of the name colors.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/border-export-color-table",
        "border_file": border_file,
        "table_out": table_out,
        "opt_class_colors": opt_class_colors,
    }
    return params


def border_export_color_table_cargs(
    params: BorderExportColorTableParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-border-export-color-table")
    cargs.append(execution.input_file(params.get("border_file", None)))
    cargs.append(params.get("table_out", None))
    if params.get("opt_class_colors", False):
        cargs.append("-class-colors")
    return cargs


def border_export_color_table_outputs(
    params: BorderExportColorTableParameters,
    execution: Execution,
) -> BorderExportColorTableOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = BorderExportColorTableOutputs(
        root=execution.output_file("."),
    )
    return ret


def border_export_color_table_execute(
    params: BorderExportColorTableParameters,
    runner: Runner | None = None,
) -> BorderExportColorTableOutputs:
    """
    border-export-color-table
    
    Write border names and colors as text.
    
    Takes the names and colors of each border, and writes it to the same format
    as -metric-label-import expects. By default, the borders are colored by
    border name, specify -class-colors to color them by class instead. The key
    values start at 1 and follow the order of the borders in the file.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderExportColorTableOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BORDER_EXPORT_COLOR_TABLE_METADATA)
    params = execution.params(params)
    cargs = border_export_color_table_cargs(params, execution)
    ret = border_export_color_table_outputs(params, execution)
    execution.run(cargs)
    return ret


def border_export_color_table(
    border_file: InputPathType,
    table_out: str,
    opt_class_colors: bool = False,
    runner: Runner | None = None,
) -> BorderExportColorTableOutputs:
    """
    border-export-color-table
    
    Write border names and colors as text.
    
    Takes the names and colors of each border, and writes it to the same format
    as -metric-label-import expects. By default, the borders are colored by
    border name, specify -class-colors to color them by class instead. The key
    values start at 1 and follow the order of the borders in the file.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        border_file: the input border file.
        table_out: output - the output text file.
        opt_class_colors: use class colors instead of the name colors.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderExportColorTableOutputs`).
    """
    params = border_export_color_table_params(
        border_file=border_file,
        table_out=table_out,
        opt_class_colors=opt_class_colors,
    )
    return border_export_color_table_execute(params, runner)


__all__ = [
    "BORDER_EXPORT_COLOR_TABLE_METADATA",
    "BorderExportColorTableOutputs",
    "border_export_color_table",
    "border_export_color_table_execute",
    "border_export_color_table_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

BORDER_RESAMPLE_METADATA = Metadata(
    id="9be294dad7cdf118a17d5ba9c35d2223b1ababca.boutiques",
    name="border-resample",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


BorderResampleParameters = typing.TypedDict('BorderResampleParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/border-resample"]],
    "border_in": InputPathType,
    "current_sphere": InputPathType,
    "new_sphere": InputPathType,
    "border_out": str,
})
BorderResampleParametersTagged = typing.TypedDict('BorderResampleParametersTagged', {
    "@type": typing.Literal["workbench/border-resample"],
    "border_in": InputPathType,
    "current_sphere": InputPathType,
    "new_sphere": InputPathType,
    "border_out": str,
})


class BorderResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `BorderResampleParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    border_out: OutputPathType
    """the output border file"""


def border_resample_params(
    border_in: InputPathType,
    current_sphere: InputPathType,
    new_sphere: InputPathType,
    border_out: str,
) -> BorderResampleParametersTagged:
    """
    Build parameters.
    
    Args:
        border_in: the border file to resample.
        current_sphere: a sphere surface with the mesh that the metric is\
            currently on.
        new_sphere: a sphere surface that is in register with <current-sphere>\
            and has the desired output mesh.
        border_out: the output border file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/border-resample",
        "border_in": border_in,
        "current_sphere": current_sphere,
        "new_sphere": new_sphere,
        "border_out": border_out,
    }
    return params


def border_resample_cargs(
    params: BorderResampleParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-border-resample")
    cargs.append(execution.input_file(params.get("border_in", None)))
    cargs.append(execution.input_file(params.get("current_sphere", None)))
    cargs.append(execution.input_file(params.get("new_sphere", None)))
    cargs.append(params.get("border_out", None))
    return cargs


def border_resample_outputs(
    params: BorderResampleParameters,
    execution: Execution,
) -> BorderResampleOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = BorderResampleOutputs(
        root=execution.output_file("."),
        border_out=execution.output_file(params.get("border_out", None)),
    )
    return ret


def border_resample_execute(
    params: BorderResampleParameters,
    runner: Runner | None = None,
) -> BorderResampleOutputs:
    """
    border-resample
    
    Resample a border file to a different mesh.
    
    Resamples a border file, given two spherical surfaces that are in register.
    Only borders that have the same structure as current-sphere will be
    resampled.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BORDER_RESAMPLE_METADATA)
    params = execution.params(params)
    cargs = border_resample_cargs(params, execution)
    ret = border_resample_outputs(params, execution)
    execution.run(cargs)
    return ret


def border_resample(
    border_in: InputPathType,
    current_sphere: InputPathType,
    new_sphere: InputPathType,
    border_out: str,
    runner: Runner | None = None,
) -> BorderResampleOutputs:
    """
    border-resample
    
    Resample a border file to a different mesh.
    
    Resamples a border file, given two spherical surfaces that are in register.
    Only borders that have the same structure as current-sphere will be
    resampled.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        border_in: the border file to resample.
        current_sphere: a sphere surface with the mesh that the metric is\
            currently on.
        new_sphere: a sphere surface that is in register with <current-sphere>\
            and has the desired output mesh.
        border_out: the output border file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderResampleOutputs`).
    """
    params = border_resample_params(
        border_in=border_in,
        current_sphere=current_sphere,
        new_sphere=new_sphere,
        border_out=border_out,
    )
    return border_resample_execute(params, runner)


__all__ = [
    "BORDER_RESAMPLE_METADATA",
    "BorderResampleOutputs",
    "border_resample",
    "border_resample_execute",
    "border_resample_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_AVERAGE_METADATA = Metadata(
    id="eb8455e8a7cbe64873a585671039f835b925b8e1.boutiques",
    name="surface-average",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceAverageSurfParameters = typing.TypedDict('SurfaceAverageSurfParameters', {
    "@type": typing.NotRequired[typing.Literal["surf"]],
    "surface": InputPathType,
    "opt_weight_weight": typing.NotRequired[float | None],
})
SurfaceAverageSurfParametersTagged = typing.TypedDict('SurfaceAverageSurfParametersTagged', {
    "@type": typing.Literal["surf"],
    "surface": InputPathType,
    "opt_weight_weight": typing.NotRequired[float | None],
})


SurfaceAverageParameters = typing.TypedDict('SurfaceAverageParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-average"]],
    "surface_out": str,
    "opt_stddev_stddev_metric_out": typing.NotRequired[str | None],
    "opt_uncertainty_uncert_metric_out": typing.NotRequired[str | None],
    "surf": typing.NotRequired[list[SurfaceAverageSurfParameters] | None],
})
SurfaceAverageParametersTagged = typing.TypedDict('SurfaceAverageParametersTagged', {
    "@type": typing.Literal["workbench/surface-average"],
    "surface_out": str,
    "opt_stddev_stddev_metric_out": typing.NotRequired[str | None],
    "opt_uncertainty_uncert_metric_out": typing.NotRequired[str | None],
    "surf": typing.NotRequired[list[SurfaceAverageSurfParameters] | None],
})


def surface_average_surf_params(
    surface: InputPathType,
    opt_weight_weight: float | None = None,
) -> SurfaceAverageSurfParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: a surface file to average.
        opt_weight_weight: specify a weighted average: the weight to use\
            (default 1).
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "surf",
        "surface": surface,
    }
    if opt_weight_weight is not None:
        params["opt_weight_weight"] = opt_weight_weight
    return params


def surface_average_surf_cargs(
    params: SurfaceAverageSurfParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-surf")
    cargs.append(execution.input_file(params.get("surface", None)))
    if params.get("opt_weight_weight", None) is not None:
        cargs.extend([
            "-weight",
            str(params.get("opt_weight_weight", None))
        ])
    return cargs


class SurfaceAverageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceAverageParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    surface_out: OutputPathType
    """the output averaged surface"""
    opt_stddev_stddev_metric_out: OutputPathType | None
    """compute 3D sample standard deviation: the output metric for 3D sample
    standard deviation"""
    opt_uncertainty_uncert_metric_out: OutputPathType | None
    """compute caret5 'uncertainty': the output metric for uncertainty"""


def surface_average_params(
    surface_out: str,
    opt_stddev_stddev_metric_out: str | None = None,
    opt_uncertainty_uncert_metric_out: str | None = None,
    surf: list[SurfaceAverageSurfParameters] | None = None,
) -> SurfaceAverageParametersTagged:
    """
    Build parameters.
    
    Args:
        surface_out: the output averaged surface.
        opt_stddev_stddev_metric_out: compute 3D sample standard deviation: the\
            output metric for 3D sample standard deviation.
        opt_uncertainty_uncert_metric_out: compute caret5 'uncertainty': the\
            output metric for uncertainty.
        surf: specify a surface to include in the average.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-average",
        "surface_out": surface_out,
    }
    if opt_stddev_stddev_metric_out is not None:
        params["opt_stddev_stddev_metric_out"] = opt_stddev_stddev_metric_out
    if opt_uncertainty_uncert_metric_out is not None:
        params["opt_uncertainty_uncert_metric_out"] = opt_uncertainty_uncert_metric_out
    if surf is not None:
        params["surf"] = surf
    return params


def surface_average_cargs(
    params: SurfaceAverageParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-average")
    cargs.append(params.get("surface_out", None))
    if params.get("opt_stddev_stddev_metric_out", None) is not None:
        cargs.extend([
            "-stddev",
            params.get("opt_stddev_stddev_metric_out", None)
        ])
    if params.get("opt_uncertainty_uncert_metric_out", None) is not None:
        cargs.extend([
            "-uncertainty",
            params.get("opt_uncertainty_uncert_metric_out", None)
        ])
    if params.get("surf", None) is not None:
        cargs.extend([a for c in [surface_average_surf_cargs(s, execution) for s in params.get("surf", None)] for a in c])
    return cargs


def surface_average_outputs(
    params: SurfaceAverageParameters,
    execution: Execution,
) -> SurfaceAverageOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceAverageOutputs(
        root=execution.output_file("."),
        surface_out=execution.output_file(params.get("surface_out", None)),
        opt_stddev_stddev_metric_out=execution.output_file(params.get("opt_stddev_stddev_metric_out", None)) if (params.get("opt_stddev_stddev_metric_out") is not None) else None,
        opt_uncertainty_uncert_metric_out=execution.output_file(params.get("opt_uncertainty_uncert_metric_out", None)) if (params.get("opt_uncertainty_uncert_metric_out") is not None) else None,
    )
    return ret


def surface_average_execute(
    params: SurfaceAverageParameters,
    runner: Runner | None = None,
) -> SurfaceAverageOutputs:
    """
    surface-average
    
    Average surface files together.
    
    The 3D sample standard deviation is computed as 'sqrt(sum(squaredlength(xyz
    - mean(xyz)))/(n - 1))'.
    
    Uncertainty is a legacy measure used in caret5, and is computed as
    'sum(length(xyz - mean(xyz)))/n'.
    
    When weights are used, the 3D sample standard deviation treats them as
    reliability weights.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceAverageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_AVERAGE_METADATA)
    params = execution.params(params)
    cargs = surface_average_cargs(params, execution)
    ret = surface_average_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_average(
    surface_out: str,
    opt_stddev_stddev_metric_out: str | None = None,
    opt_uncertainty_uncert_metric_out: str | None = None,
    surf: list[SurfaceAverageSurfParameters] | None = None,
    runner: Runner | None = None,
) -> SurfaceAverageOutputs:
    """
    surface-average
    
    Average surface files together.
    
    The 3D sample standard deviation is computed as 'sqrt(sum(squaredlength(xyz
    - mean(xyz)))/(n - 1))'.
    
    Uncertainty is a legacy measure used in caret5, and is computed as
    'sum(length(xyz - mean(xyz)))/n'.
    
    When weights are used, the 3D sample standard deviation treats them as
    reliability weights.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface_out: the output averaged surface.
        opt_stddev_stddev_metric_out: compute 3D sample standard deviation: the\
            output metric for 3D sample standard deviation.
        opt_uncertainty_uncert_metric_out: compute caret5 'uncertainty': the\
            output metric for uncertainty.
        surf: specify a surface to include in the average.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceAverageOutputs`).
    """
    params = surface_average_params(
        surface_out=surface_out,
        opt_stddev_stddev_metric_out=opt_stddev_stddev_metric_out,
        opt_uncertainty_uncert_metric_out=opt_uncertainty_uncert_metric_out,
        surf=surf,
    )
    return surface_average_execute(params, runner)


__all__ = [
    "SURFACE_AVERAGE_METADATA",
    "SurfaceAverageOutputs",
    "surface_average",
    "surface_average_execute",
    "surface_average_params",
    "surface_average_surf_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

METADATA_REMOVE_PROVENANCE_METADATA = Metadata(
    id="4800e85a5fdc741153c992271baa48d72065973e.boutiques",
    name="metadata-remove-provenance",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


MetadataRemoveProvenanceParameters = typing.TypedDict('MetadataRemoveProvenanceParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/metadata-remove-provenance"]],
    "input_file": str,
    "output_file": str,
})
MetadataRemoveProvenanceParametersTagged = typing.TypedDict('MetadataRemoveProvenanceParametersTagged', {
    "@type": typing.Literal["workbench/metadata-remove-provenance"],
    "input_file": str,
    "output_file": str,
})


class MetadataRemoveProvenanceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetadataRemoveProvenanceParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def metadata_remove_provenance_params(
    input_file: str,
    output_file: str,
) -> MetadataRemoveProvenanceParametersTagged:
    """
    Build parameters.
    
    Args:
        input_file: the file to remove provenance information from.
        output_file: output - the name to save the modified file as.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/metadata-remove-provenance",
        "input_file": input_file,
        "output_file": output_file,
    }
    return params


def metadata_remove_provenance_cargs(
    params: MetadataRemoveProvenanceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metadata-remove-provenance")
    cargs.append(params.get("input_file", None))
    cargs.append(params.get("output_file", None))
    return cargs


def metadata_remove_provenance_outputs(
    params: MetadataRemoveProvenanceParameters,
    execution: Execution,
) -> MetadataRemoveProvenanceOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetadataRemoveProvenanceOutputs(
        root=execution.output_file("."),
    )
    return ret


def metadata_remove_provenance_execute(
    params: MetadataRemoveProvenanceParameters,
    runner: Runner | None = None,
) -> MetadataRemoveProvenanceOutputs:
    """
    metadata-remove-provenance
    
    Remove provenance information from file metadata.
    
    Removes the provenance metadata fields added by workbench during processing.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetadataRemoveProvenanceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METADATA_REMOVE_PROVENANCE_METADATA)
    params = execution.params(params)
    cargs = metadata_remove_provenance_cargs(params, execution)
    ret = metadata_remove_provenance_outputs(params, execution)
    execution.run(cargs)
    return ret


def metadata_remove_provenance(
    input_file: str,
    output_file: str,
    runner: Runner | None = None,
) -> MetadataRemoveProvenanceOutputs:
    """
    metadata-remove-provenance
    
    Remove provenance information from file metadata.
    
    Removes the provenance metadata fields added by workbench during processing.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        input_file: the file to remove provenance information from.
        output_file: output - the name to save the modified file as.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetadataRemoveProvenanceOutputs`).
    """
    params = metadata_remove_provenance_params(
        input_file=input_file,
        output_file=output_file,
    )
    return metadata_remove_provenance_execute(params, runner)


__all__ = [
    "METADATA_REMOVE_PROVENANCE_METADATA",
    "MetadataRemoveProvenanceOutputs",
    "metadata_remove_provenance",
    "metadata_remove_provenance_execute",
    "metadata_remove_provenance_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_PARCEL_SMOOTHING_METADATA = Metadata(
    id="d9e82f37b708bec47857be4b7298c862173c768b.boutiques",
    name="volume-parcel-smoothing",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeParcelSmoothingParameters = typing.TypedDict('VolumeParcelSmoothingParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-parcel-smoothing"]],
    "data_volume": InputPathType,
    "label_volume": InputPathType,
    "kernel": float,
    "volume_out": str,
    "opt_fwhm": bool,
    "opt_fix_zeros": bool,
    "opt_subvolume_subvol": typing.NotRequired[str | None],
})
VolumeParcelSmoothingParametersTagged = typing.TypedDict('VolumeParcelSmoothingParametersTagged', {
    "@type": typing.Literal["workbench/volume-parcel-smoothing"],
    "data_volume": InputPathType,
    "label_volume": InputPathType,
    "kernel": float,
    "volume_out": str,
    "opt_fwhm": bool,
    "opt_fix_zeros": bool,
    "opt_subvolume_subvol": typing.NotRequired[str | None],
})


class VolumeParcelSmoothingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeParcelSmoothingParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_parcel_smoothing_params(
    data_volume: InputPathType,
    label_volume: InputPathType,
    kernel: float,
    volume_out: str,
    opt_fwhm: bool = False,
    opt_fix_zeros: bool = False,
    opt_subvolume_subvol: str | None = None,
) -> VolumeParcelSmoothingParametersTagged:
    """
    Build parameters.
    
    Args:
        data_volume: the volume to smooth.
        label_volume: a label volume containing the parcels to smooth.
        kernel: the size of the gaussian smoothing kernel in mm, as sigma by\
            default.
        volume_out: the output volume.
        opt_fwhm: smoothing kernel size is FWHM, not sigma.
        opt_fix_zeros: treat zero values as not being data.
        opt_subvolume_subvol: select a single subvolume to smooth: the\
            subvolume number or name.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-parcel-smoothing",
        "data_volume": data_volume,
        "label_volume": label_volume,
        "kernel": kernel,
        "volume_out": volume_out,
        "opt_fwhm": opt_fwhm,
        "opt_fix_zeros": opt_fix_zeros,
    }
    if opt_subvolume_subvol is not None:
        params["opt_subvolume_subvol"] = opt_subvolume_subvol
    return params


def volume_parcel_smoothing_cargs(
    params: VolumeParcelSmoothingParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-parcel-smoothing")
    cargs.append(execution.input_file(params.get("data_volume", None)))
    cargs.append(execution.input_file(params.get("label_volume", None)))
    cargs.append(str(params.get("kernel", None)))
    cargs.append(params.get("volume_out", None))
    if params.get("opt_fwhm", False):
        cargs.append("-fwhm")
    if params.get("opt_fix_zeros", False):
        cargs.append("-fix-zeros")
    if params.get("opt_subvolume_subvol", None) is not None:
        cargs.extend([
            "-subvolume",
            params.get("opt_subvolume_subvol", None)
        ])
    return cargs


def volume_parcel_smoothing_outputs(
    params: VolumeParcelSmoothingParameters,
    execution: Execution,
) -> VolumeParcelSmoothingOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeParcelSmoothingOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
    )
    return ret


def volume_parcel_smoothing_execute(
    params: VolumeParcelSmoothingParameters,
    runner: Runner | None = None,
) -> VolumeParcelSmoothingOutputs:
    """
    volume-parcel-smoothing
    
    Smooth parcels in a volume separately.
    
    The volume is smoothed within each label in the label volume using data only
    from within the label. Equivalent to running volume smoothing with ROIs
    matching each label separately, then adding the resulting volumes, but
    faster.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeParcelSmoothingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_PARCEL_SMOOTHING_METADATA)
    params = execution.params(params)
    cargs = volume_parcel_smoothing_cargs(params, execution)
    ret = volume_parcel_smoothing_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_parcel_smoothing(
    data_volume: InputPathType,
    label_volume: InputPathType,
    kernel: float,
    volume_out: str,
    opt_fwhm: bool = False,
    opt_fix_zeros: bool = False,
    opt_subvolume_subvol: str | None = None,
    runner: Runner | None = None,
) -> VolumeParcelSmoothingOutputs:
    """
    volume-parcel-smoothing
    
    Smooth parcels in a volume separately.
    
    The volume is smoothed within each label in the label volume using data only
    from within the label. Equivalent to running volume smoothing with ROIs
    matching each label separately, then adding the resulting volumes, but
    faster.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        data_volume: the volume to smooth.
        label_volume: a label volume containing the parcels to smooth.
        kernel: the size of the gaussian smoothing kernel in mm, as sigma by\
            default.
        volume_out: the output volume.
        opt_fwhm: smoothing kernel size is FWHM, not sigma.
        opt_fix_zeros: treat zero values as not being data.
        opt_subvolume_subvol: select a single subvolume to smooth: the\
            subvolume number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeParcelSmoothingOutputs`).
    """
    params = volume_parcel_smoothing_params(
        data_volume=data_volume,
        label_volume=label_volume,
        kernel=kernel,
        volume_out=volume_out,
        opt_fwhm=opt_fwhm,
        opt_fix_zeros=opt_fix_zeros,
        opt_subvolume_subvol=opt_subvolume_subvol,
    )
    return volume_parcel_smoothing_execute(params, runner)


__all__ = [
    "VOLUME_PARCEL_SMOOTHING_METADATA",
    "VolumeParcelSmoothingOutputs",
    "volume_parcel_smoothing",
    "volume_parcel_smoothing_execute",
    "volume_parcel_smoothing_params",
]
